@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-01-14'; # DATE
+our $DATE = '2022-01-23'; # DATE
 our $DIST = 'Text-Table-Any'; # DIST
-our $VERSION = '0.109'; # VERSION
+our $VERSION = '0.110'; # VERSION
 
 our %BACKEND_FEATURES = (
     "Term::Table" => {
@@ -57,30 +57,40 @@ our %BACKEND_FEATURES = (
         header_row => 1,
         separate_rows => 0,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::CSV" => {
         rows => 1,
         header_row => 1,
         separate_rows => 0,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::HTML" => {
         rows => 1,
         header_row => 1,
         separate_rows => 0,
         title => 1,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::HTML::DataTables" => {
         rows => 1,
         header_row => 1,
         separate_rows => 0,
         title => 1,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::LTSV" => {
         rows => 1,
         header_row => 0,
         separate_rows => 0,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::Manifold" => {
         rows => 1,
@@ -93,72 +103,96 @@ our %BACKEND_FEATURES = (
         header_row => 1,
         separate_rows => 1,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::Org" => {
         rows => 1,
         header_row => 1,
         separate_rows => 1,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::Paragraph" => {
         rows => 1,
         header_row => 1,
         separate_rows => 0,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::Sprintf" => {
         rows => 1,
         header_row => 1,
         separate_rows => 1,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::TickitWidget" => {
         rows => 1,
         header_row => 1,
         separate_rows => 0,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::Tiny" => {
         rows => 1,
         header_row => 1,
         separate_rows => 1,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::TinyBorderStyle" => {
         rows => 1,
         header_row => 1,
         separate_rows => 1,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::TinyColor" => {
         rows => 1,
         header_row => 1,
         separate_rows => 1,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::TinyColorWide" => {
         rows => 1,
         header_row => 1,
         separate_rows => 1,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::TinyWide" => {
         rows => 1,
         header_row => 1,
         separate_rows => 1,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::TSV" => {
         rows => 1,
         header_row => 0,
         separate_rows => 0,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::Table::XLSX" => {
         rows => 1,
         header_row => 1,
         separate_rows => 0,
         title => 0,
+        backend_opts => 1,
+        backend_opts_note => "Backend-specific options (backend_opts) will be passed to table() or generate_table() directly",
     },
     "Text::TabularDisplay" => {
         rows => 1,
@@ -278,12 +312,14 @@ sub table {
         return Text::Table::ASV::table(
             rows => $rows,
             header_row => $header_row,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         );
     } elsif ($backend eq 'Text::Table::CSV') {
         require Text::Table::CSV;
         return Text::Table::CSV::table(
             rows => $rows,
             header_row => $header_row,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         );
     } elsif ($backend eq 'Text::Table::HTML') {
         require Text::Table::HTML;
@@ -291,6 +327,7 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             (title => $params{title}) x !!defined($params{title}),
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         );
     } elsif ($backend eq 'Text::Table::HTML::DataTables') {
         require Text::Table::HTML::DataTables;
@@ -298,11 +335,13 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             (title => $params{title}) x !!defined($params{title}),
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         );
     } elsif ($backend eq 'Text::Table::LTSV') {
         require Text::Table::LTSV;
         return Text::Table::LTSV::table(
             rows => $rows,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         );
     } elsif ($backend eq 'Text::Table::Manifold') {
         require Text::Table::Manifold;
@@ -321,6 +360,7 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             separate_rows => $separate_rows,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         ) . "\n";
     } elsif ($backend eq 'Text::Table::Org') {
         require Text::Table::Org;
@@ -328,12 +368,14 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             separate_rows => $separate_rows,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         );
     } elsif ($backend eq 'Text::Table::Paragraph') {
         require Text::Table::Paragraph;
         return Text::Table::Paragraph::table(
             rows => $rows,
             header_row => $header_row,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         );
     } elsif ($backend eq 'Text::Table::Sprintf') {
         require Text::Table::Sprintf;
@@ -341,12 +383,14 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             separate_rows => $separate_rows,
-        ) . "\n";
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
+        );
     } elsif ($backend eq 'Text::Table::TickitWidget') {
         require Text::Table::TickitWidget;
         return Text::Table::TickitWidget::table(
             rows => $rows,
             header_row => $header_row,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         ) . "\n";
     } elsif ($backend eq 'Text::Table::Tiny') {
         require Text::Table::Tiny;
@@ -354,6 +398,7 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             separate_rows => $separate_rows,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         ) . "\n";
     } elsif ($backend eq 'Text::Table::TinyBorderStyle') {
         require Text::Table::TinyBorderStyle;
@@ -361,6 +406,7 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             separate_rows => $separate_rows,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         ) . "\n";
     } elsif ($backend eq 'Text::Table::TinyColor') {
         require Text::Table::TinyColor;
@@ -368,6 +414,7 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             separate_rows => $separate_rows,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         ) . "\n";
     } elsif ($backend eq 'Text::Table::TinyColorWide') {
         require Text::Table::TinyColorWide;
@@ -375,6 +422,7 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             separate_rows => $separate_rows,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         ) . "\n";
     } elsif ($backend eq 'Text::Table::TinyWide') {
         require Text::Table::TinyWide;
@@ -382,17 +430,20 @@ sub table {
             rows => $rows,
             header_row => $header_row,
             separate_rows => $separate_rows,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         ) . "\n";
     } elsif ($backend eq 'Text::Table::TSV') {
         require Text::Table::TSV;
         return Text::Table::TSV::table(
             rows => $rows,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         );
     } elsif ($backend eq 'Text::Table::XLSX') {
         require Text::Table::XLSX;
         return Text::Table::XLSX::table(
             rows => $rows,
             header_row => $header_row,
+            defined($params{backend_opts}) ? %{$params{backend_opts}} : (),
         );
     } elsif ($backend eq 'Text::TabularDisplay') {
         require Text::TabularDisplay;
@@ -430,7 +481,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.109 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2022-01-14.
+This document describes version 0.110 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2022-01-23.
 
 =head1 SYNOPSIS
 
@@ -626,37 +677,37 @@ backends:
 
 Support matrix for each backend:
 
- +-------------------------------+------------+------+---------------+-------+
- | backend                       | header_row | rows | separate_rows | title |
- +-------------------------------+------------+------+---------------+-------+
- | Term::Table                   | 1          | 1    | 0             | 0     |
- | Term::TablePrint              | 1          | 1    | 0             | 0     |
- | Text::ANSITable               | 1          | 1    | 1             | 0     |
- | Text::ASCIITable              | 1          | 1    | 0             | 0     |
- | Text::FormatTable             | 0          | 1    | 0             | 0     |
- | Text::MarkdownTable           | 1          | 1    | 0             | 0     |
- | Text::Table                   | 0          | 1    | 0             | 0     |
- | Text::Table::ASV              | 1          | 1    | 0             | 0     |
- | Text::Table::CSV              | 1          | 1    | 0             | 0     |
- | Text::Table::HTML             | 1          | 1    | 0             | 1     |
- | Text::Table::HTML::DataTables | 1          | 1    | 0             | 1     |
- | Text::Table::LTSV             | 0          | 1    | 0             | 0     |
- | Text::Table::Manifold         | 1          | 1    | 0             | 0     |
- | Text::Table::More             | 1          | 1    | 1             | 0     |
- | Text::Table::Org              | 1          | 1    | 1             | 0     |
- | Text::Table::Paragraph        | 1          | 1    | 0             | 0     |
- | Text::Table::Sprintf          | 1          | 1    | 1             | 0     |
- | Text::Table::TSV              | 0          | 1    | 0             | 0     |
- | Text::Table::TickitWidget     | 1          | 1    | 0             | 0     |
- | Text::Table::Tiny             | 1          | 1    | 1             | 0     |
- | Text::Table::TinyBorderStyle  | 1          | 1    | 1             | 0     |
- | Text::Table::TinyColor        | 1          | 1    | 1             | 0     |
- | Text::Table::TinyColorWide    | 1          | 1    | 1             | 0     |
- | Text::Table::TinyWide         | 1          | 1    | 1             | 0     |
- | Text::Table::XLSX             | 1          | 1    | 0             | 0     |
- | Text::TabularDisplay          | 0          | 1    | 0             | 0     |
- | Text::UnicodeBox::Table       | 1          | 1    | 0             | 0     |
- +-------------------------------+------------+------+---------------+-------+
+ +-------------------------------+--------------+------------------------------------------------------------------------------------------------+------------+------+---------------+-------+
+ | backend                       | backend_opts | backend_opts_note                                                                              | header_row | rows | separate_rows | title |
+ +-------------------------------+--------------+------------------------------------------------------------------------------------------------+------------+------+---------------+-------+
+ | Term::Table                   |              |                                                                                                | 1          | 1    | 0             | 0     |
+ | Term::TablePrint              |              |                                                                                                | 1          | 1    | 0             | 0     |
+ | Text::ANSITable               |              |                                                                                                | 1          | 1    | 1             | 0     |
+ | Text::ASCIITable              |              |                                                                                                | 1          | 1    | 0             | 0     |
+ | Text::FormatTable             |              |                                                                                                | 0          | 1    | 0             | 0     |
+ | Text::MarkdownTable           |              |                                                                                                | 1          | 1    | 0             | 0     |
+ | Text::Table                   |              |                                                                                                | 0          | 1    | 0             | 0     |
+ | Text::Table::ASV              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 0             | 0     |
+ | Text::Table::CSV              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 0             | 0     |
+ | Text::Table::HTML             | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 0             | 1     |
+ | Text::Table::HTML::DataTables | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 0             | 1     |
+ | Text::Table::LTSV             | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0          | 1    | 0             | 0     |
+ | Text::Table::Manifold         |              |                                                                                                | 1          | 1    | 0             | 0     |
+ | Text::Table::More             | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 1             | 0     |
+ | Text::Table::Org              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 1             | 0     |
+ | Text::Table::Paragraph        | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 0             | 0     |
+ | Text::Table::Sprintf          | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 1             | 0     |
+ | Text::Table::TSV              | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 0          | 1    | 0             | 0     |
+ | Text::Table::TickitWidget     | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 0             | 0     |
+ | Text::Table::Tiny             | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 1             | 0     |
+ | Text::Table::TinyBorderStyle  | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 1             | 0     |
+ | Text::Table::TinyColor        | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 1             | 0     |
+ | Text::Table::TinyColorWide    | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 1             | 0     |
+ | Text::Table::TinyWide         | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 1             | 0     |
+ | Text::Table::XLSX             | 1            | Backend-specific options (backend_opts) will be passed to table() or generate_table() directly | 1          | 1    | 0             | 0     |
+ | Text::TabularDisplay          |              |                                                                                                | 0          | 1    | 0             | 0     |
+ | Text::UnicodeBox::Table       |              |                                                                                                | 1          | 1    | 0             | 0     |
+ +-------------------------------+--------------+------------------------------------------------------------------------------------------------+------------+------+---------------+-------+
 
 =item * rows
 
@@ -684,6 +735,14 @@ Optional. Str. Title of the table.
 Currently the only backends supporting this are C<Text::Table::HTML> and
 C<Text::Table::HTML::DataTables>.
 
+=item * backend_opts
+
+Optional. Hashref. Pass backend-specific options to the backend module. Not all
+backend modules support this, but all backend modules that have interface
+following C<Text::Table::Tiny> should support this. Also note that as the list
+of common options is expanded, a previously backend-specific option might be
+available later as a common option.
+
 =back
 
 =head2 backends
@@ -726,7 +785,7 @@ beyond that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
